function dot= Rigbod_Dynam2_LVLH(x,Tc,Td,f)                    % s/c Dynamics with CMG
global J JI d2r r2d wo
global Th nt Jloc Jdir CB2L

% dot= Rigbod_Dynam2_LVLH(x,Tc,Td,f)
% Space Station Dynamics in the Local Vertical Local Horizontal plane
% State Variables (x)
% x(1-3)   = body rates (wb)
% x(4-6)   = Attitude LVLH
% x(7-9)   = CMG Momentum in body (hcmg)
% Inputs:
% Tc(3)    = Control Torque (ft-lb)
% Td(3)    = Disturbance Torque (ft-lb)
% f(nt)    = RCS jet thrusts (lbf)

dot= zeros(15,1);
wb  = x(1:3);                                                     % body rates
the = x(4:6);                                                     % Vehicle Atttitude LVLH
hcmg= x(7:9);                                                     % CMG Momentum

cphi= cos(the(1)); sphi= sin(the(1));
cthe= cos(the(2)); sthe= sin(the(2));
cpsi= cos(the(3)); spsi= sin(the(3));

c= [-sin(the(2))*cos(the(3)); ...                                 % Gravity Gradient terms
    cos(the(1))*sin(the(2))*sin(the(3)) + sin(the(1))*cos(the(2)); ...
   -sin(the(1))*sin(the(2))*sin(the(3)) + cos(the(1))*cos(the(2))];

CB2L= [cpsi, -cphi*spsi,  sphi*spsi; ...                          % Body to LVLH Transform
        0,    cphi,      -sphi; ...
        0,    sphi*cpsi,  cphi*cpsi]/cpsi;

Tr= zeros(3,1);                                                   % Calculate Thruster Moments
for i=1:nt 
    Tr= Tr + f(i)*cross(Jloc(:,i), Jdir(:,i));                    % Total RCS Moment (ft-lb)
end

dot(1:3)= JI*(-cross(wb,J*wb) + 3*wo^2*cross(c,J*c)-Tc +Td +Tr);  % Rate of Change of body rates wb-dot
dot(4:6)= CB2L*wb + [0, wo, 0]';                                  % rate of Euler angls wrt LVLH
dot(7:9)= -cross(wb,hcmg) + Tc;                                   % Rate of CMG Momentum in body
dot(10:12)= J*wb + hcmg;                                          % System Momentum
dot(13:15)= CB2L*wb + [0, wo, 0]';                                % Rates in LVLH